==> haskell-tamarin-prover-accountability-1.10.0-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-accountability.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tamarin-prover-accountability
version:              1.10.0
visibility:           public
id:                   tamarin-prover-accountability-1.10.0-2pnPyYmZNeC9kSbk3eJOBA
key:                  tamarin-prover-accountability-1.10.0-2pnPyYmZNeC9kSbk3eJOBA
license:              LicenseRef-GPL
copyright:            (c) 2019-2021 Robert Künnemann, Kevin Morio & Yavor Ivanov
maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Kevin Morio <kevin.morio@cispa.de>,
    Yavor Ivanov <yavor.ivanov@cispa.de>

homepage:             https://tamarin-prover.github.io/
synopsis:             Library for accountability for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

    This library provides support for accountability verification.

category:             Theorem Provers
abi:                  bf505dba3ecd3b9bbb8a1e1532fbd813
exposed:              True
exposed-modules:      Accountability Accountability.Generation
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/tamarin-prover-accountability-1.10.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/tamarin-prover-accountability-1.10.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-accountability
hs-libraries:
    HStamarin-prover-accountability-1.10.0-2pnPyYmZNeC9kSbk3eJOBA

depends:
    aeson-2.1.2.1-GayFRV4oUv8L6a1HjAAkY
    aeson-pretty-0.8.10-E7IDwurm2yW1CQHlkouSyF base-4.16.4.0
    binary-0.8.9.0 bytestring-0.11.4.0 containers-0.6.5.1
    deepseq-1.4.6.1 dlist-1.0-HCxoMn9TirQDgPCFxho7O exceptions-0.10.4
    fclabels-2.0.5.1-1LJomkB8yiI9vimVxxr1RC mtl-2.2.2
    parallel-3.2.2.0-KgDyPHm89eYAjQsIhXthC1 parsec-3.1.15.0
    process-1.6.16.0 raw-strings-qq-1.1-H0wHvIVgY406DfNVW3VYlH
    safe-0.3.21-AbNyMoK0ADF8qenYHSmRn2
    tamarin-prover-term-1.10.0-FmI9jKQUYL7Jb07hb1p02C
    tamarin-prover-theory-1.10.0-5AWEQe8dNJ1Kaun9pswUvB
    tamarin-prover-utils-1.10.0-AzJh47PDAJ6DL4elCTyuPL text-1.2.5.0
    transformers-0.5.6.2 uniplate-1.6.13-FaD6TQEF5AsKuFvJZRWdSY

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-accountability/html/tamarin-prover-accountability.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-accountability/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-accountability-1.10.0-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-accountability.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tamarin-prover-accountability
version:              1.10.0
visibility:           public
id:                   tamarin-prover-accountability-1.10.0-GlynaphL3sW6I4CzNV8un6
key:                  tamarin-prover-accountability-1.10.0-GlynaphL3sW6I4CzNV8un6
license:              LicenseRef-GPL
copyright:            (c) 2019-2021 Robert Künnemann, Kevin Morio & Yavor Ivanov
maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Kevin Morio <kevin.morio@cispa.de>,
    Yavor Ivanov <yavor.ivanov@cispa.de>

homepage:             https://tamarin-prover.github.io/
synopsis:             Library for accountability for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

    This library provides support for accountability verification.

category:             Theorem Provers
abi:                  45589833dcc4f2b4db5d1ba642bfe9d6
exposed:              True
exposed-modules:      Accountability Accountability.Generation
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/tamarin-prover-accountability-1.10.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/tamarin-prover-accountability-1.10.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-accountability
hs-libraries:
    HStamarin-prover-accountability-1.10.0-GlynaphL3sW6I4CzNV8un6

depends:
    aeson-2.1.2.1-F8qbdML4nHt6X1eCfIdgPU
    aeson-pretty-0.8.10-CNsp08cOz8XAprKrNzdbwP base-4.16.4.0
    binary-0.8.9.0 bytestring-0.11.4.0 containers-0.6.5.1
    deepseq-1.4.6.1 dlist-1.0-HCxoMn9TirQDgPCFxho7O exceptions-0.10.4
    fclabels-2.0.5.1-1LJomkB8yiI9vimVxxr1RC mtl-2.2.2
    parallel-3.2.2.0-KgDyPHm89eYAjQsIhXthC1 parsec-3.1.15.0
    process-1.6.16.0 raw-strings-qq-1.1-H0wHvIVgY406DfNVW3VYlH
    safe-0.3.21-AbNyMoK0ADF8qenYHSmRn2
    tamarin-prover-term-1.10.0-LROUm5TwS3xAOrFQpSl8pV
    tamarin-prover-theory-1.10.0-DziivaHkUWy3W6yXslQEDZ
    tamarin-prover-utils-1.10.0-EoRpflkPtjrFl0OM2YWKM5 text-1.2.5.0
    transformers-0.5.6.2 uniplate-1.6.13-FaD6TQEF5AsKuFvJZRWdSY

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-accountability/html/tamarin-prover-accountability.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-accountability/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
